
# Slot: is_a




URI: [linkml:permissible_value_is_a](https://w3id.org/linkml/permissible_value_is_a)


## Domain and Range

permissible_value &#8594;  <sub>0..1</sub> permissible_value

## Parents

 *  is_a: is_a

## Children


## Used by

 * permissible_value
